==> cmsmadesimple-1.6.4.tgz: cms/modules/FileManager/lang/ext/es_ES.php <==
<?php
$lang['friendlyname'] = 'Administrador de Archivos';
$lang['permission'] = 'Usos del m&oacute;dulo de Administraci&oacute;n de Archivos';
$lang['permissionadvanced'] = 'Usos avanzados del m&oacute;dulo de Administraci&oacute;n de Archivos';
$lang['moddescription'] = 'Manejo de archivos y directorios en la secci&oacute;n de subida de archivos de cmsms';
$lang['installed'] = 'Se ha instalado la versi&oacute;n %s de Administraci&oacute;n de Archivos';
$lang['postinstall'] = 'Se ha instalado el m&oacute;dulo de Administraci&oacute;n de Archivos';
$lang['uninstalled'] = 'Se ha des-instalado el m&oacute;dulo de Administraci&oacute;n de Archivos';
$lang['really_uninstall'] = '&iquest;Est&aacute; seguro que quiere des-instalar el m&oacute;dulo de Administraci&oacute;n de Archivos?';
$lang['upgraded'] = 'Se ha actualizado el m&oacute;dulo de Administraci&oacute;n de Archivos a la versi&oacute;n %s';
$lang['fileview'] = 'Ver archivo';
$lang['switchtofileview'] = 'Cambiar a vista de archivo';
$lang['settings'] = 'Configuraciones';
$lang['savesettings'] = 'Guardar configuraciones';
$lang['filename'] = 'Nombre de Archivo';
$lang['fileinfo'] = 'Info de archivo';
$lang['fileowner'] = 'Due&ntilde;o de archivo';
$lang['fileperms'] = 'Permisos';
$lang['filesize'] = 'Tama&ntilde;o';
$lang['filedate'] = 'Fecha';
$lang['actions'] = 'Acciones';
$lang['delete'] = 'Eliminar';
$lang['notwritable'] = 'No se pude escribir';
$lang['filetoobig'] = 'es demasiado grande. En envio se ha cancelado.';
$lang['unknown'] = 'Desconocido';
$lang['fileoutsideuploads'] = 'No tiene permiso de modificar archivos fuera del directorio &#039;uploads&#039; (Esto requiere el que se active el permiso de Administraci&oacute;n Avanzada de Archivos)';
$lang['writable'] = 'De escritura';
$lang['writeprotected'] = 'Protegido contra escritura';
$lang['bytes'] = 'bytes ';
$lang['kb'] = 'kb ';
$lang['mb'] = 'mb ';
$lang['files'] = 'archivos';
$lang['bytesin'] = 'bytes en';
$lang['in'] = 'en';
$lang['file'] = 'archivo';
$lang['fileno'] = 'N&deg; de archivo';
$lang['subdirs'] = 'subdirectorios';
$lang['subdir'] = 'subdirectorio';
$lang['and'] = 'y';
$lang['confirmsingledelete'] = '&iquest;Est&aacute; usted seguro?';
$lang['confirmsingledirdelete'] = '&iquest;Est&aacute; seguro que este directorio debe eliminarse?';
$lang['dirtreedeletesuccess'] = 'El directorio, incluido su contenido, fue eliminado con &eacute;xito.';
$lang['dirtreedeletefail'] = 'Ha ocurrido un error mientras se eliminaba el directorio. Sin embargo, algo del contenido puede haber sido eliminado.';
$lang['singlefiledeletesuccess'] = 'El archivo se elimin&oacute; con &eacute;xito';
$lang['filedeletesuccess'] = 'fue eliminado con &eacute;xito';
$lang['singlefiledeletefail'] = 'Ha ocurrido un error al tratar de eliminar el archivo';
$lang['filedeletefail'] = 'no fue eliminado debido a un error';
$lang['singledirdeletesuccess'] = 'El directorio se elimin&oacute; con &eacute;xito';
$lang['singledirdeletefail'] = 'Ha ocurrido un error tratando de eliminar el directorio (&iquest;estar&aacute; vac&iacute;o?)';
$lang['deleteselected'] = 'Eliminar los archivos seleccionados';
$lang['confirmselected'] = '&iquest;Est&aacute; seguro?';
$lang['confirmdeleteselected'] = '&iquest;Esta seguro que los archivos seleccionados deben ser eliminados?';
$lang['deleteselectedcancelled'] = 'Se cancel&oacute; la eliminaci&oacute;n de los archivos seleccionados';
$lang['recursetext'] = 'Recursividad de sub-directorios';
$lang['nofilesselected'] = 'No hay archivos seleccionados';
$lang['moveselected'] = 'Mover los archivos seleccionados';
$lang['copyselected'] = 'Copiar los archivos seleccionados';
$lang['selecttargetdir'] = 'Seleccione una carpeta destino para mover/copiar';
$lang['movedto'] = 'movido a';
$lang['copiedto'] = 'copiado a';
$lang['couldnotmove'] = 'no se pudo mover';
$lang['couldnotcopy'] = 'no se pudo copiar';
$lang['rename'] = 'Renombrar';
$lang['newname'] = 'Nuevo nombre:';
$lang['renamesuccess'] = 'Archivo renombrado con &eacute;xito';
$lang['renamefailure'] = 'No se pudo renombrar el archivo';
$lang['renamecancelled'] = 'Cambio de nombre cancelado';
$lang['owner'] = 'Propietario';
$lang['group'] = 'Grupo';
$lang['others'] = 'Otros';
$lang['newpermissions'] = 'Nuevos permisos:';
$lang['setpermissions'] = 'Establecer permisos';
$lang['permissionstyle'] = 'Estilo de permiso';
$lang['rwxstyle'] = 'estilo rwx ';
$lang['755style'] = 'estilo 755';
$lang['quickmode'] = 'chmod (como 777) r&aacute;pido';
$lang['chmod'] = 'Cambiar permisos';
$lang['chmodselected'] = 'Cambiar permisos de archivos seleccionados';
$lang['chmodsuccess'] = 'El archivo obtuvo nuevos permisos exitosamente';
$lang['chmodfailure'] = 'Fall&oacute; el cambio de permisos del archivo';
$lang['chmodcancelled'] = 'Se cancel&oacute; el cambio de permisos';
$lang['dirchmodfailmulti'] = 'No se pudo hacer el cambio de los permisos del directorio, pero algo en su contenido puede que haya recibido los nuevos permisos.';
$lang['dirchmodsuccessmulti'] = 'Se cambiaron los permisos y el contenido exitosamente ';
$lang['dirchmodsuccess'] = 'El directorio recibi&oacute; los nuevos permisos exitosamente';
$lang['dirchmodfailure'] = 'El cambio de permisos del directorio fall&oacute;';
$lang['dirnotemptyconfirm'] = 'Este directorio no est&aacute; vac&iacute;o. &iquest;Realmente desea eliminarlo junto con su contenido, incluyendo los sub-directorios?';
$lang['dirtreedeletecancelled'] = 'Se cancel&oacute; la eliminaci&oacute;n del directorio';
$lang['imsure'] = 'Estoy seguro';
$lang['cancel'] = 'Cancelar';
$lang['ok'] = 'OK ';
$lang['uploadnewfile'] = 'Subir nuevo archivo(s):';
$lang['unpackafterupload'] = '&iquest;Descomprimir el archivo luego de subir (solo tgz y la mayor&iacute;a de los archivos zip)?';
$lang['uploadsuccess'] = 'fue subido con &eacute;xito';
$lang['uploadfail'] = 'fall&oacute; subir el archivo';
$lang['unpacksuccess'] = 'fue descomprimido con &eacute;xito';
$lang['unpackfail'] = 'fall&oacute; con el siguiente error: ';
$lang['packfileopenfail'] = 'No se pudo abrir el archivo para descomprimir (&iquest;quiz&aacute; un formato no soportado?)';
$lang['packfilewritefail'] = 'No se pudo abrir el archivo &amp;s para escribir';
$lang['currentpath'] = 'Paso actual:';
$lang['newdirname'] = 'Crear nuevo directorio:';
$lang['newdirsuccess'] = 'El directorio se creo con &eacute;xito';
$lang['newdirfail'] = 'Ha ocurrido un error tratando de crear el directorio';
$lang['invalidnewdir'] = 'Nombre del nuevo directorio no puede contener caracteres como /, \ y &#039;..&#039; ';
$lang['filedateformat'] = 'm/d/Y H:m:s ';
$lang['iconsize'] = 'Tama&ntilde;o de icono';
$lang['smallicons'] = 'Peque&ntilde;os iconos';
$lang['largeicons'] = 'Grandes iconos';
$lang['thousanddelimiter'] = 'Delimitador de miles';
$lang['none'] = 'Ninguno';
$lang['space'] = 'espacio';
$lang['showthumbnails'] = 'Mostrar vistas miniatura';
$lang['showthumbnailshelp'] = 'Habilitar eso, mostrara las vistas miniatura de imagenes, si estas existen. Si se desabilita simplemente se mostraran todos los archivos.';
$lang['uploadfilesto'] = 'Subiendo archivos a:';
$lang['uploadview'] = 'Subir archivos';
$lang['uploadboxes'] = 'Cantidad de rampas p/subir';
$lang['nothinguploaded'] = 'Nada subido';
$lang['unsupportedarchive'] = 'Formato de archivo no soportado';
$lang['uploadmethod'] = 'M&eacute;todo de subida';
$lang['uploaderstandard'] = 'M&eacute;todo de carga html standard (permite descomprimir)';
$lang['enableadvanced'] = '&iquest;Habilitamos modo avanzado?';
$lang['advancedhelp'] = 'Dejamos ganar acceso a todo el sistema de archivos de cmsms, no s&oacute;lo /upload/ (si es permitido)';
$lang['showhiddenfileshelp'] = 'S&oacute;lo efectivo con el modo avanzado habilitado';
$lang['showhiddenfiles'] = 'Mostrar archivos escondidos';
$lang['settingsconfirmsingledelete'] = '&iquest;Confirmar la eliminaci&oacute;n de un archivo?';
$lang['settingssaved'] = 'Configuraci&oacute;n guardada';
$lang['help'] = '		<h3>&iquest;Qu&eacute; hace esto?</h3>
		<p>Este m&oacute;dulo provee funciones de manejo de archivos, eventualmente y con expectativas de reemplazar al ya viejo sistema de manejo de archivos</p>
		<h3>&iquest;C&oacute;mo se usa?</h3>
		<p>Seleccione al mismo en el men&uacute; de contenido del &aacute;rea de administraci&oacute;n. Seguramente el viejo sistema de archivos est&aacute; a&uacute;n all&iacute;, elija el que est&aacute; m&aacute;s abajo dentro del men&uacute;.</p>';
$lang['utma'] = '156861353.661434885.1227567621.1241554232.1242674634.67';
$lang['utmz'] = '156861353.1241473702.63.28.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/board,30.0.html|utmcmd=referral';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.8.2p0.tgz: cms/modules/FileManager/lang/ext/es_ES.php <==
<?php
$lang['friendlyname'] = 'Administrador de Archivos';
$lang['permission'] = 'Usos del m&oacute;dulo de Administraci&oacute;n de Archivos';
$lang['permissionadvanced'] = 'Usos avanzados del m&oacute;dulo de Administraci&oacute;n de Archivos';
$lang['moddescription'] = 'Manejo de archivos y directorios en la secci&oacute;n de subida de archivos de cmsms';
$lang['installed'] = 'Se ha instalado la versi&oacute;n %s de Administraci&oacute;n de Archivos';
$lang['postinstall'] = 'Se ha instalado el m&oacute;dulo de Administraci&oacute;n de Archivos';
$lang['uninstalled'] = 'Se ha des-instalado el m&oacute;dulo de Administraci&oacute;n de Archivos';
$lang['really_uninstall'] = '&iquest;Est&aacute; seguro que quiere des-instalar el m&oacute;dulo de Administraci&oacute;n de Archivos?';
$lang['upgraded'] = 'Se ha actualizado el m&oacute;dulo de Administraci&oacute;n de Archivos a la versi&oacute;n %s';
$lang['fileview'] = 'Ver archivo';
$lang['switchtofileview'] = 'Cambiar a vista de archivo';
$lang['settings'] = 'Configuraciones';
$lang['savesettings'] = 'Guardar configuraciones';
$lang['filename'] = 'Nombre de Archivo';
$lang['fileinfo'] = 'Info de archivo';
$lang['fileowner'] = 'Due&ntilde;o de archivo';
$lang['fileperms'] = 'Permisos';
$lang['filesize'] = 'Tama&ntilde;o';
$lang['filedate'] = 'Fecha';
$lang['actions'] = 'Acciones';
$lang['delete'] = 'Eliminar';
$lang['notwritable'] = 'No se pude escribir';
$lang['filetoobig'] = 'es demasiado grande. En envio se ha cancelado.';
$lang['unknown'] = 'Desconocido';
$lang['fileoutsideuploads'] = 'No tiene permiso de modificar archivos fuera del directorio &#039;uploads&#039; (Esto requiere el que se active el permiso de Administraci&oacute;n Avanzada de Archivos)';
$lang['writable'] = 'De escritura';
$lang['writeprotected'] = 'Protegido contra escritura';
$lang['bytes'] = 'bytes ';
$lang['kb'] = 'kb ';
$lang['mb'] = 'mb ';
$lang['files'] = 'archivos';
$lang['bytesin'] = 'bytes en';
$lang['in'] = 'en';
$lang['file'] = 'archivo';
$lang['fileno'] = 'N&deg; de archivo';
$lang['subdirs'] = 'subdirectorios';
$lang['subdir'] = 'subdirectorio';
$lang['and'] = 'y';
$lang['confirmsingledelete'] = '&iquest;Est&aacute; usted seguro?';
$lang['confirmsingledirdelete'] = '&iquest;Est&aacute; seguro que este directorio debe eliminarse?';
$lang['dirtreedeletesuccess'] = 'El directorio, incluido su contenido, fue eliminado con &eacute;xito.';
$lang['dirtreedeletefail'] = 'Ha ocurrido un error mientras se eliminaba el directorio. Sin embargo, algo del contenido puede haber sido eliminado.';
$lang['singlefiledeletesuccess'] = 'El archivo se elimin&oacute; con &eacute;xito';
$lang['filedeletesuccess'] = 'fue eliminado con &eacute;xito';
$lang['singlefiledeletefail'] = 'Ha ocurrido un error al tratar de eliminar el archivo';
$lang['filedeletefail'] = 'no fue eliminado debido a un error';
$lang['singledirdeletesuccess'] = 'El directorio se elimin&oacute; con &eacute;xito';
$lang['singledirdeletefail'] = 'Ha ocurrido un error tratando de eliminar el directorio (&iquest;estar&aacute; vac&iacute;o?)';
$lang['deleteselected'] = 'Eliminar los archivos seleccionados';
$lang['confirmselected'] = '&iquest;Est&aacute; seguro?';
$lang['confirmdeleteselected'] = '&iquest;Esta seguro que los archivos seleccionados deben ser eliminados?';
$lang['deleteselectedcancelled'] = 'Se cancel&oacute; la eliminaci&oacute;n de los archivos seleccionados';
$lang['recursetext'] = 'Recursividad de sub-directorios';
$lang['nofilesselected'] = 'No hay archivos seleccionados';
$lang['moveselected'] = 'Mover los archivos seleccionados';
$lang['copyselected'] = 'Copiar los archivos seleccionados';
$lang['selecttargetdir'] = 'Seleccione una carpeta destino para mover/copiar';
$lang['movedto'] = 'movido a';
$lang['copiedto'] = 'copiado a';
$lang['couldnotmove'] = 'no se pudo mover';
$lang['couldnotcopy'] = 'no se pudo copiar';
$lang['rename'] = 'Renombrar';
$lang['newname'] = 'Nuevo nombre:';
$lang['renamesuccess'] = 'Archivo renombrado con &eacute;xito';
$lang['renamefailure'] = 'No se pudo renombrar el archivo';
$lang['renamecancelled'] = 'Cambio de nombre cancelado';
$lang['owner'] = 'Propietario';
$lang['group'] = 'Grupo';
$lang['others'] = 'Otros';
$lang['newpermissions'] = 'Nuevos permisos:';
$lang['setpermissions'] = 'Establecer permisos';
$lang['permissionstyle'] = 'Estilo de permiso';
$lang['rwxstyle'] = 'estilo rwx ';
$lang['755style'] = 'estilo 755';
$lang['quickmode'] = 'chmod (como 777) r&aacute;pido';
$lang['chmod'] = 'Cambiar permisos';
$lang['chmodselected'] = 'Cambiar permisos de archivos seleccionados';
$lang['chmodsuccess'] = 'El archivo obtuvo nuevos permisos exitosamente';
$lang['chmodfailure'] = 'Fall&oacute; el cambio de permisos del archivo';
$lang['chmodcancelled'] = 'Se cancel&oacute; el cambio de permisos';
$lang['dirchmodfailmulti'] = 'No se pudo hacer el cambio de los permisos del directorio, pero algo en su contenido puede que haya recibido los nuevos permisos.';
$lang['dirchmodsuccessmulti'] = 'Se cambiaron los permisos y el contenido exitosamente ';
$lang['dirchmodsuccess'] = 'El directorio recibi&oacute; los nuevos permisos exitosamente';
$lang['dirchmodfailure'] = 'El cambio de permisos del directorio fall&oacute;';
$lang['dirnotemptyconfirm'] = 'Este directorio no est&aacute; vac&iacute;o. &iquest;Realmente desea eliminarlo junto con su contenido, incluyendo los sub-directorios?';
$lang['dirtreedeletecancelled'] = 'Se cancel&oacute; la eliminaci&oacute;n del directorio';
$lang['imsure'] = 'Estoy seguro';
$lang['cancel'] = 'Cancelar';
$lang['ok'] = 'OK ';
$lang['uploadnewfile'] = 'Subir nuevo archivo(s):';
$lang['unpackafterupload'] = '&iquest;Descomprimir el archivo luego de subir (solo tgz y la mayor&iacute;a de los archivos zip)?';
$lang['uploadsuccess'] = 'fue subido con &eacute;xito';
$lang['uploadfail'] = 'fall&oacute; subir el archivo';
$lang['unpacksuccess'] = 'fue descomprimido con &eacute;xito';
$lang['unpackfail'] = 'fall&oacute; con el siguiente error: ';
$lang['packfileopenfail'] = 'No se pudo abrir el archivo para descomprimir (&iquest;quiz&aacute; un formato no soportado?)';
$lang['packfilewritefail'] = 'No se pudo abrir el archivo &amp;s para escribir';
$lang['containsillegalchars'] = 'El nombre de archivo contiene caracteres inv&aacute;lidos (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['currentpath'] = 'Paso actual:';
$lang['newdirname'] = 'Crear nuevo directorio:';
$lang['newdirsuccess'] = 'El directorio se creo con &eacute;xito';
$lang['newdirfail'] = 'Ha ocurrido un error tratando de crear el directorio';
$lang['invalidnewdir'] = 'Nombre del nuevo directorio no puede contener caracteres como /, \ y &#039;..&#039; ';
$lang['filedateformat'] = 'm/d/Y H:m:s ';
$lang['iconsize'] = 'Tama&ntilde;o de icono';
$lang['smallicons'] = 'Peque&ntilde;os iconos';
$lang['largeicons'] = 'Grandes iconos';
$lang['thousanddelimiter'] = 'Delimitador de miles';
$lang['none'] = 'Ninguno';
$lang['space'] = 'espacio';
$lang['showthumbnails'] = 'Mostrar vistas miniatura';
$lang['showthumbnailshelp'] = 'Habilitar eso, mostrara las vistas miniatura de imagenes, si estas existen. Si se desabilita simplemente se mostraran todos los archivos.';
$lang['uploadfilesto'] = 'Subiendo archivos a:';
$lang['uploadview'] = 'Subir archivos';
$lang['uploadboxes'] = 'Cantidad de rampas p/subir';
$lang['nothinguploaded'] = 'Nada subido';
$lang['unsupportedarchive'] = 'Formato de archivo no soportado';
$lang['uploadmethod'] = 'M&eacute;todo de subida';
$lang['uploaderstandard'] = 'M&eacute;todo de carga html standard (permite descomprimir)';
$lang['enableadvanced'] = '&iquest;Habilitamos modo avanzado?';
$lang['advancedhelp'] = 'Dejamos ganar acceso a todo el sistema de archivos de cmsms, no s&oacute;lo /upload/ (si es permitido)';
$lang['showhiddenfileshelp'] = 'S&oacute;lo efectivo con el modo avanzado habilitado';
$lang['showhiddenfiles'] = 'Mostrar archivos escondidos';
$lang['settingsconfirmsingledelete'] = '&iquest;Confirmar la eliminaci&oacute;n de un archivo?';
$lang['settingssaved'] = 'Configuraci&oacute;n guardada';
$lang['help'] = '		<h3>&iquest;Qu&eacute; hace esto?</h3>
		<p>Este m&oacute;dulo provee funciones de manejo de archivos, eventualmente y con expectativas de reemplazar al ya viejo sistema de manejo de archivos</p>
		<h3>&iquest;C&oacute;mo se usa?</h3>
		<p>Seleccione al mismo en el men&uacute; de contenido del &aacute;rea de administraci&oacute;n. Seguramente el viejo sistema de archivos est&aacute; a&uacute;n all&iacute;, elija el que est&aacute; m&aacute;s abajo dentro del men&uacute;.</p>';
$lang['utma'] = '156861353.1791238199.1256157318.1256620466.1256855476.6';
$lang['utmz'] = '156861353.1256620490.5.5.utmccn=(organic)|utmcsr=google|utmctr=cms made simple pretty urls|utmcmd=organic';
$lang['qca'] = 'P0-1140984805-1256189057107';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>
